Stan Math Library: stan::math::sum_v_vari Class Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Static Protected Member Functions | Protected Attributes | List of all members
stan::math::sum_v_vari Class Reference

Class for sums of variables constructed with standard vectors. More...

`#include <sum.hpp>`

Inheritance diagram for stan::math::sum_v_vari:

## Public Member Functions
| sum_v_vari (double value, vari **v, size_t length)
| sum_v_vari (const std::vector< var > &v1)
virtual void | chain ()
| Apply the chain rule to this variable based on the variables on which it depends. More...
Public Member Functions inherited from stan::math::vari
| vari (const double x)
| Construct a variable implementation from a value. More...
| vari (const double x, bool stacked)
virtual | ~vari ()
| Throw an illegal argument exception. More...
void | init_dependent ()
| Initialize the adjoint for this (dependent) variable to 1. More...
void | set_zero_adjoint ()
| Set the adjoint value of this variable to 0. More...

## Static Protected Member Functions
static double | sum_of_val (const std::vector< var > &v)

## Protected Attributes
vari ** | v_
size_t | length_

## Additional Inherited Members
Static Public Member Functions inherited from stan::math::vari
static void * | operator new (size_t nbytes)
| Allocate memory from the underlying memory pool. More...
static void | operator delete (void *)
| Delete a pointer from the underlying memory pool. More...
Public Attributes inherited from stan::math::vari
const double | val_
| The value of this variable. More...
double | adj_
| The adjoint of this variable, which is the partial derivative of this variable with respect to the root variable. More...

## Detailed Description

Class for sums of variables constructed with standard vectors.

There's an extension for Eigen matrices.

Definition at line 14 of file sum.hpp.

## Constructor & Destructor Documentation

stan::math::sum_v_vari::sum_v_vari | ( | double | value,
|  | vari ** | v,
|  | size_t | length
| ) |  |
| inlineexplicit

Definition at line 27 of file sum.hpp.

stan::math::sum_v_vari::sum_v_vari | ( | const std::vector< var > & | v1 | ) |
| inlineexplicit

Definition at line 31 of file sum.hpp.

## Member Function Documentation

virtual void stan::math::sum_v_vari::chain | ( |  | ) |
| inlinevirtual

Apply the chain rule to this variable based on the variables on which it depends.

The base implementation in this class is a no-op.

Reimplemented from stan::math::vari.

Definition at line 40 of file sum.hpp.

static double stan::math::sum_v_vari::sum_of_val | ( | const std::vector< var > & | v | ) |
| inlinestaticprotected

Definition at line 19 of file sum.hpp.

## Member Data Documentation

size_t stan::math::sum_v_vari::length_
| protected

Definition at line 17 of file sum.hpp.

vari** stan::math::sum_v_vari::v_
| protected

Definition at line 16 of file sum.hpp.

The documentation for this class was generated from the following file:

- stan/math/rev/arr/fun/sum.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.